# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: traceable_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='traceable_config.proto',
  package='ai.traceable.agent.config.v1',
  syntax='proto3',
  serialized_options=b'Z-github.com/Traceableai/agent-config/gen/go/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16traceable_config.proto\x12\x1c\x61i.traceable.agent.config.v1\x1a\x1egoogle/protobuf/wrappers.proto\"\x84\x01\n\x0b\x41gentConfig\x12.\n\x03opa\x18\x01 \x01(\x0b\x32!.ai.traceable.agent.config.v1.Opa\x12\x45\n\x0f\x62locking_config\x18\x02 \x01(\x0b\x32,.ai.traceable.agent.config.v1.BlockingConfig\"\x9c\x01\n\x03Opa\x12+\n\x07\x65nabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\x08\x65ndpoint\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x13poll_period_seconds\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\xf5\x02\n\x0e\x42lockingConfig\x12+\n\x07\x65nabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\tdebug_log\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x44\n\x0bmodsecurity\x18\x03 \x01(\x0b\x32/.ai.traceable.agent.config.v1.ModsecurityConfig\x12\x31\n\revaluate_body\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12K\n\x0fregion_blocking\x18\x05 \x01(\x0b\x32\x32.ai.traceable.agent.config.v1.RegionBlockingConfig\x12\x41\n\rremote_config\x18\x06 \x01(\x0b\x32*.ai.traceable.agent.config.v1.RemoteConfig\"@\n\x11ModsecurityConfig\x12+\n\x07\x65nabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"C\n\x14RegionBlockingConfig\x12+\n\x07\x65nabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xa5\x01\n\x0cRemoteConfig\x12+\n\x07\x65nabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\x08\x65ndpoint\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x13poll_period_seconds\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB/Z-github.com/Traceableai/agent-config/gen/go/v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_AGENTCONFIG = _descriptor.Descriptor(
  name='AgentConfig',
  full_name='ai.traceable.agent.config.v1.AgentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='opa', full_name='ai.traceable.agent.config.v1.AgentConfig.opa', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blocking_config', full_name='ai.traceable.agent.config.v1.AgentConfig.blocking_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=221,
)


_OPA = _descriptor.Descriptor(
  name='Opa',
  full_name='ai.traceable.agent.config.v1.Opa',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='ai.traceable.agent.config.v1.Opa.enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='ai.traceable.agent.config.v1.Opa.endpoint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poll_period_seconds', full_name='ai.traceable.agent.config.v1.Opa.poll_period_seconds', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=380,
)


_BLOCKINGCONFIG = _descriptor.Descriptor(
  name='BlockingConfig',
  full_name='ai.traceable.agent.config.v1.BlockingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='ai.traceable.agent.config.v1.BlockingConfig.enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug_log', full_name='ai.traceable.agent.config.v1.BlockingConfig.debug_log', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modsecurity', full_name='ai.traceable.agent.config.v1.BlockingConfig.modsecurity', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evaluate_body', full_name='ai.traceable.agent.config.v1.BlockingConfig.evaluate_body', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region_blocking', full_name='ai.traceable.agent.config.v1.BlockingConfig.region_blocking', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_config', full_name='ai.traceable.agent.config.v1.BlockingConfig.remote_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=383,
  serialized_end=756,
)


_MODSECURITYCONFIG = _descriptor.Descriptor(
  name='ModsecurityConfig',
  full_name='ai.traceable.agent.config.v1.ModsecurityConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='ai.traceable.agent.config.v1.ModsecurityConfig.enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=758,
  serialized_end=822,
)


_REGIONBLOCKINGCONFIG = _descriptor.Descriptor(
  name='RegionBlockingConfig',
  full_name='ai.traceable.agent.config.v1.RegionBlockingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='ai.traceable.agent.config.v1.RegionBlockingConfig.enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=824,
  serialized_end=891,
)


_REMOTECONFIG = _descriptor.Descriptor(
  name='RemoteConfig',
  full_name='ai.traceable.agent.config.v1.RemoteConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='ai.traceable.agent.config.v1.RemoteConfig.enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='ai.traceable.agent.config.v1.RemoteConfig.endpoint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poll_period_seconds', full_name='ai.traceable.agent.config.v1.RemoteConfig.poll_period_seconds', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=894,
  serialized_end=1059,
)

_AGENTCONFIG.fields_by_name['opa'].message_type = _OPA
_AGENTCONFIG.fields_by_name['blocking_config'].message_type = _BLOCKINGCONFIG
_OPA.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_OPA.fields_by_name['endpoint'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_OPA.fields_by_name['poll_period_seconds'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_BLOCKINGCONFIG.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_BLOCKINGCONFIG.fields_by_name['debug_log'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_BLOCKINGCONFIG.fields_by_name['modsecurity'].message_type = _MODSECURITYCONFIG
_BLOCKINGCONFIG.fields_by_name['evaluate_body'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_BLOCKINGCONFIG.fields_by_name['region_blocking'].message_type = _REGIONBLOCKINGCONFIG
_BLOCKINGCONFIG.fields_by_name['remote_config'].message_type = _REMOTECONFIG
_MODSECURITYCONFIG.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_REGIONBLOCKINGCONFIG.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_REMOTECONFIG.fields_by_name['enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_REMOTECONFIG.fields_by_name['endpoint'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_REMOTECONFIG.fields_by_name['poll_period_seconds'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
DESCRIPTOR.message_types_by_name['AgentConfig'] = _AGENTCONFIG
DESCRIPTOR.message_types_by_name['Opa'] = _OPA
DESCRIPTOR.message_types_by_name['BlockingConfig'] = _BLOCKINGCONFIG
DESCRIPTOR.message_types_by_name['ModsecurityConfig'] = _MODSECURITYCONFIG
DESCRIPTOR.message_types_by_name['RegionBlockingConfig'] = _REGIONBLOCKINGCONFIG
DESCRIPTOR.message_types_by_name['RemoteConfig'] = _REMOTECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AgentConfig = _reflection.GeneratedProtocolMessageType('AgentConfig', (_message.Message,), {
  'DESCRIPTOR' : _AGENTCONFIG,
  '__module__' : 'traceable_config_pb2'
  # @@protoc_insertion_point(class_scope:ai.traceable.agent.config.v1.AgentConfig)
  })
_sym_db.RegisterMessage(AgentConfig)

Opa = _reflection.GeneratedProtocolMessageType('Opa', (_message.Message,), {
  'DESCRIPTOR' : _OPA,
  '__module__' : 'traceable_config_pb2'
  # @@protoc_insertion_point(class_scope:ai.traceable.agent.config.v1.Opa)
  })
_sym_db.RegisterMessage(Opa)

BlockingConfig = _reflection.GeneratedProtocolMessageType('BlockingConfig', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKINGCONFIG,
  '__module__' : 'traceable_config_pb2'
  # @@protoc_insertion_point(class_scope:ai.traceable.agent.config.v1.BlockingConfig)
  })
_sym_db.RegisterMessage(BlockingConfig)

ModsecurityConfig = _reflection.GeneratedProtocolMessageType('ModsecurityConfig', (_message.Message,), {
  'DESCRIPTOR' : _MODSECURITYCONFIG,
  '__module__' : 'traceable_config_pb2'
  # @@protoc_insertion_point(class_scope:ai.traceable.agent.config.v1.ModsecurityConfig)
  })
_sym_db.RegisterMessage(ModsecurityConfig)

RegionBlockingConfig = _reflection.GeneratedProtocolMessageType('RegionBlockingConfig', (_message.Message,), {
  'DESCRIPTOR' : _REGIONBLOCKINGCONFIG,
  '__module__' : 'traceable_config_pb2'
  # @@protoc_insertion_point(class_scope:ai.traceable.agent.config.v1.RegionBlockingConfig)
  })
_sym_db.RegisterMessage(RegionBlockingConfig)

RemoteConfig = _reflection.GeneratedProtocolMessageType('RemoteConfig', (_message.Message,), {
  'DESCRIPTOR' : _REMOTECONFIG,
  '__module__' : 'traceable_config_pb2'
  # @@protoc_insertion_point(class_scope:ai.traceable.agent.config.v1.RemoteConfig)
  })
_sym_db.RegisterMessage(RemoteConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
